	.include "MSP430F41X.h"

LCD_DIV_32		.equ	000h
LCD_DIV_64		.equ	008h
LCD_DIV_128		.equ	010h
LCD_DIV_256		.equ	018h

XCAP18PF		.equ 	070h

RAM_orig  .set		 00200h		 ; Free Memory start address
ROM_orig  .set		 0E000h		 ; ROM start address
USER_END  .set		 0FFFFh		 ; RAM end address
SP_orig   .set		 00280h		 ; stackpointer

;************************************************************************
; Reset : Initialize processor
;************************************************************************

;	.sect "MAIN",ROM_orig
RESET
	mov #SP_orig,SP				   ; initialize stackpointer
	mov #(WDT_HOLD+WDT_WRKEY),&WDTCTL  ; Stop Watchdog Timer
;	bis.b #XCAP18PF,&FLL_CTL0       ;set load capacitance for xtal

	; Setup Basic Timer for LCD operation
;	mov.b #(LCD_DIV_32+024h),&BTCTL
;	mov.b #(LCD_DIV_64+024h),&BTCTL
	mov.b #(LCD_DIV_128+024h),&BTCTL
;	mov.b #(LCD_DIV_256+024h),&BTCTL

	mov.b #(LCD_DIV_64+023h),&BTCTL

	; Turn on Basic Timer interrupts
	bis.b #BTIE,&IE2

	; Setup port functions
	mov.b #0F0h,&P2SEL
	mov.b #0FFh,&P3SEL
	mov.b #0FFh,&P4SEL
	mov.b #0FFh,&P5SEL
	
	; Setup P2.3/P2.2 twiddles
	bis.b #00Ch,&P2DIR

	; Setup LCD
	mov.b #(LCDLASTSEG23|LCDMODE_4MUX|LCDSHOW|LCDMODULEON),&LCDCTL
	; Setup LCD data
	mov.b #037h,&LCDMEM1	
	mov.b #05Fh,&LCDMEM2	
	mov.b #02Fh,&LCDMEM3	
	mov.b #03Dh,&LCDMEM4	
	mov.b #007h,&LCDMEM5	
	mov.b #07Ch,&LCDMEM6	
	mov.b #07Fh,&LCDMEM7	
	mov.b #0FFh,&LCDMEM8	
	mov.b #0FFh,&LCDMEM9	
	mov.b #0FFh,&LCDMEM10	
	mov.b #0FFh,&LCDMEM11	

	; Clear LED bit
	bic.b #001h,&P1OUT
	; Setup Blinky
	mov.b #051h,&P1DIR

	; Initialize demo counters
	mov #1,R5
	mov #1,R8
	clr R6

	; Initialize accessory state
	mov #Display_0,R4

	eint

;******************************************************************************
; Mainloop
;******************************************************************************
LoopTop
;	xor.b #001h,&P1OUT    ; Toggle LED
	; Go to sleep
	bis #(CPUOFF+SCG1+SCG0),SR	

LoopDemoStuff_Next
	; Demo the symbology
	call R4
	jmp LoopTop

Display_0
	mov #Display_1,R4
;	bis.b #008h,&P2OUT
;	bic.b #004h,&P2OUT

	; Clear all
	mov.b #012h,&LCDMEM8
	mov.b #081h,&LCDMEM9
	mov.b #09Fh,&LCDMEM10
	mov.b #010h,&LCDMEM11

	ret

Display_1
	mov #Display_2,R4
	
	; Increment
	mov.b #012h,&LCDMEM8
	mov.b #081h,&LCDMEM9
	mov.b #0DFh,&LCDMEM10
	mov.b #020h,&LCDMEM11
	ret

Display_2
	mov #Display_3,R4

	; Increment
	mov.b #022h,&LCDMEM8
	mov.b #013h,&LCDMEM9
	mov.b #0DFh,&LCDMEM10
	mov.b #024h,&LCDMEM11

	ret

Display_3
	mov #Display_4,R4

	; Increment
	mov.b #022h,&LCDMEM8
	mov.b #013h,&LCDMEM9
	mov.b #0FDh,&LCDMEM10
	mov.b #024h,&LCDMEM11

	ret

Display_4
	mov #Display_5,R4

	; Increment
	mov.b #042h,&LCDMEM8
	mov.b #017h,&LCDMEM9
	mov.b #0FDh,&LCDMEM10
	mov.b #046h,&LCDMEM11

	ret

Display_5
	mov #Display_6,R4

	; Increment
	mov.b #042h,&LCDMEM8
	mov.b #027h,&LCDMEM9
	mov.b #0FDh,&LCDMEM10
	mov.b #046h,&LCDMEM11

	ret

Display_6
	mov #Display_7,R4
	bic.b #008h,&P2OUT
	bis.b #004h,&P2OUT

	; Increment
	mov.b #082h,&LCDMEM8
	mov.b #02Fh,&LCDMEM9
	mov.b #00Dh,&LCDMEM10
	mov.b #047h,&LCDMEM11

	ret

Display_7
	mov #Display_8,R4

	; Increment
	mov.b #082h,&LCDMEM8
	mov.b #02Fh,&LCDMEM9
	mov.b #009h,&LCDMEM10
	mov.b #083h,&LCDMEM11

	ret

Display_8
	mov #Display_9,R4

	; Increment
	mov.b #00Bh,&LCDMEM8
	mov.b #04Fh,&LCDMEM9
	mov.b #019h,&LCDMEM10
	mov.b #083h,&LCDMEM11

	ret

Display_9
	mov #Display_10,R4

	; Increment
	mov.b #00Bh,&LCDMEM8
	mov.b #04Fh,&LCDMEM9
	mov.b #099h,&LCDMEM10
	mov.b #081h,&LCDMEM11

	ret

Display_10
	mov #Display_11,R4

	mov.b #00Eh,&LCDMEM8
	mov.b #04Fh,&LCDMEM9
	mov.b #090h,&LCDMEM10
	mov.b #011h,&LCDMEM11

	ret

Display_11
	mov #Display_0,R4

	; Clear all
	mov.b #00Eh,&LCDMEM8
	mov.b #08Fh,&LCDMEM9
	mov.b #0D0h,&LCDMEM10
	mov.b #011h,&LCDMEM11

	ret

Int_BT
;	xor.b #040h,&P1OUT	  ; Toggle P1.6
	; Wake processor
	bic #(SCG1+SCG0+CPUOFF),0(SP)
	reti

; * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
; Interrupt vectors
; * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *

	.sect	  "Int_Vect",USER_END-31
	.word	  Int_BT			  ; Basic Timer
	.word	  RESET				  ; no source
	.word	  RESET				  ; no source
	.word	  RESET				  ; no source
	.word	  RESET				  ; no source
	.word	  RESET				  ; no source
	.word	  RESET				  ; no source
	.word	  RESET				  ; no source
	.word	  RESET				  ; no source
	.word	  RESET				  ; no source
	.word	  RESET				  ; no source
	.word	  RESET				  ; no source
	.word	  RESET				  ; no source
	.word	  RESET				  ; no source
	.word	  RESET				  ; NMI, Osc. fault
	.word	  RESET				  ; POR, ext. Reset, Watchdog
	.end